python\_package package
=======================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   odsbox.con_i
   odsbox.datamatrices_to_pandas
   odsbox.jaquel
   odsbox.model_cache
   odsbox.submatrix_to_pandas
   odsbox.transaction
   odsbox.unit_catalog
   odsbox.unit_utils

Submodules
----------

python\_package.setup module
----------------------------

.. automodule:: odsbox.setup
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: odsbox
   :members:
   :undoc-members:
   :show-inheritance:
